@@ -17,7 +17,7 @@ import nfldb.team
 
 __pdoc__ = {}
 
-api_version = 5
+api_version = 6
 __pdoc__['api_version'] = \
     """
     The schema version that this library corresponds to. When the schema
@@ -276,15 +276,10 @@ class Tx (object):
         # No biscuits for the psycopg2 author. Changed the public API in
         # 2.5 in a very very subtle way.
         # In 2.4, apparently `name` cannot be `None`. Why? I don't know.
-        if psycopg2.__version__.startswith('2.5'):
-            self.__cursor = self.__conn.cursor(name=self.__name,
-                                               cursor_factory=self.__factory)
+        if self.__name is None:
+            self.__cursor = self.__conn.cursor(cursor_factory=self.__factory)
         else:
-            if self.__name is None:
-                self.__cursor = self.__conn.cursor(
-                    cursor_factory=self.__factory)
-            else:
-                self.__cursor = self.__conn.cursor(self.__name, self.__factory)
+            self.__cursor = self.__conn.cursor(self.__name, self.__factory)
         c = self.__cursor
 
         # class _ (object):
@@ -768,3 +763,13 @@ def _migrate_5(c):
             ALTER COLUMN height TYPE usmallint USING height::usmallint,
             ALTER COLUMN weight TYPE usmallint USING weight::usmallint;
     ''')
+
+def _migrate_6(c):
+    c.execute('''
+        ALTER TABLE meta DROP CONSTRAINT meta_week_check;
+        ALTER TABLE game DROP CONSTRAINT game_week_check;
+        ALTER TABLE meta ADD CONSTRAINT meta_week_check
+            CHECK (week >= 0 AND week <= 25);
+        ALTER TABLE game ADD CONSTRAINT game_week_check
+            CHECK (week >= 0 AND week <= 25);
+    ''')
